@@ -1,6 +1,6 @@
 package Perl6::Pod::Block::code;
 
-#$Id$
+#$Id: code.pm 585 2009-08-05 06:51:38Z zag $
 
 =pod
 
@@ -10,9 +10,15 @@ Perl6::Pod::Block::code - Verbatim pre-formatted sample source code
 
 =head1 SYNOPSIS
 
-     =begin code
-      print "Ok";
-     =end code
+    =for format :xml
+    <root><test/></root>
+
+    =for format :xhtml
+    <div><br/></div>
+
+    =for format :docbook
+    <title>Test chapter</title>
+    <para>This is a test para</para>
 
 =head1 DESCRIPTION
 
@@ -43,78 +49,30 @@ sub to_xml {
     return $parser->_make_xml_element($self)->add_content($parser->mk_cdata(@_));
 }
 
-=head2 to_xhtml
-
-    =code
-    test code
-
-Render to:
-
-    <pre><code>
-        test code
-    </code></pre>
-=cut
-
 sub to_xhtml { 
     my $self = shift;
     my $parser = shift;
     my $el = $parser->mk_element('code')->insert_to( $parser->mk_element('pre') );
-    $el->add_content( $self->_make_elements($parser,@_) );
+    $el->add_content( $parser->mk_characters( @_));
 }
 
-=head2 to_docbook
-
-    =code
-    test code
-
-Render to:
-
-     <chapter><programlisting><![CDATA[    test code
-     ]]></programlisting></chapter>
-
-=cut
-
-sub to_docbook {
-    my $self = shift;
-    my $parser = shift;
-    my $el = $parser->mk_element('programlisting');
-    $el->add_content( $self->_make_elements($parser,@_) );
+sub on_para {
+    my ($self , $parser, $txt)  = @_;
+    return  $txt;
 }
 
-#add escaping
-sub _make_elements {
-    my $self = shift;
-    my $parser = shift;
-    my @res  = ();
-    for (@_) {
-        push @res, ref($_)
-          ? ref($_) eq 'ARRAY'
-              ? $parser->_make_elements(@$_)
-              : $_
-          : $parser->mk_characters(_html_escape($_));
-    }
-    return @res;
-}
-
-
-sub _html_escape {
-    my ( $txt ) =@_;
-    $txt   =~ s/&/&amp;/g;
-    $txt   =~ s/</&lt;/g;
-    $txt   =~ s/>/&gt;/g;
-    $txt   =~ s/"/&quot;/g;
-    $txt   =~ s/'/&apos;/g;
-    $txt
+sub on_child {
+    my ($self ,$parser, $child )= @_;
+    diag "got child!";
 }
 1;
+
 __END__
 
 
 =head1 SEE ALSO
 
-L<http://zag.ru/perl6-pod/S26.html>,
-Perldoc Pod to HTML converter: L<http://zag.ru/perl6-pod/>,
-Perl6::Pod::Lib
+L<http://perlcabal.org/syn/S26.html>
 
 =head1 AUTHOR
 
@@ -122,7 +80,7 @@ Zahatski Aliaksandr, <zag@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2010 by Zahatski Aliaksandr
+Copyright (C) 2009 by Zahatski Aliaksandr
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
