@@ -1,6 +1,6 @@
 package Perl6::Pod::Block::para;
 
-#$Id$
+#$Id: para.pm 585 2009-08-05 06:51:38Z zag $
 
 =pod
 
@@ -34,14 +34,11 @@ use warnings;
 use strict;
 use Perl6::Pod::Block;
 use base 'Perl6::Pod::Block';
-use Test::More;
-use Data::Dumper;
 
-sub to_xhtml { 
+sub to_xhtml1 { 
     my $self = shift;
     my $parser = shift;
-    my $el = $parser->mk_element('p')->add_content( $parser->_make_elements( @_));
-    return $el;
+#    my $el = $parser->mk_element('p')->add_content( $parser->mk_characters( '@_'));
 }
 
 
@@ -49,11 +46,10 @@ sub to_xhtml {
 
 __END__
 
+
 =head1 SEE ALSO
 
-L<http://zag.ru/perl6-pod/S26.html>,
-Perldoc Pod to HTML converter: L<http://zag.ru/perl6-pod/>,
-Perl6::Pod::Lib
+L<http://perlcabal.org/syn/S26.html>
 
 =head1 AUTHOR
 
@@ -61,11 +57,12 @@ Zahatski Aliaksandr, <zag@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2010 by Zahatski Aliaksandr
+Copyright (C) 2009 by Zahatski Aliaksandr
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
 at your option, any later version of Perl 5 you may have available.
 
+
 =cut
 
