@@ -1,6 +1,6 @@
 package Perl6::Pod::Directive::config;
 
-#$Id$
+#$Id: config.pm 572 2009-07-07 17:46:25Z zag $
 
 =pod
 
@@ -39,11 +39,6 @@ use Perl6::Pod::Block;
 use base 'Perl6::Pod::Block';
 use Data::Dumper;
 
-sub new {
-      my ( $class, %args ) = @_;
-      my $self = $class->SUPER::new(%args, parent_context=>1);
-}
-
 sub start {
     my $self = shift;
     my ( $parser, $attr ) = @_;
@@ -62,11 +57,10 @@ sub start {
 
 __END__
 
+
 =head1 SEE ALSO
 
-L<http://zag.ru/perl6-pod/S26.html>,
-Perldoc Pod to HTML converter: L<http://zag.ru/perl6-pod/>,
-Perl6::Pod::Lib
+L<http://perlcabal.org/syn/S26.html>
 
 =head1 AUTHOR
 
@@ -74,11 +68,12 @@ Zahatski Aliaksandr, <zag@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2010 by Zahatski Aliaksandr
+Copyright (C) 2009 by Zahatski Aliaksandr
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
 at your option, any later version of Perl 5 you may have available.
 
+
 =cut
 
