@@ -1,6 +1,6 @@
 package Perl6::Pod::Parser;
 
-#$Id$
+#$Id: Parser.pm 585 2009-08-05 06:51:38Z zag $
 
 =pod
 
@@ -22,7 +22,6 @@ DOCUMENTING !DOCUMENTING !DOCUMENTING !DOCUMENTING !DOCUMENTING !
 use warnings;
 use strict;
 use Carp;
-use open ':utf8';
 use IO::File;
 use Test::More;
 use Data::Dumper;
@@ -40,8 +39,7 @@ sub new {
     unless ( exists $self->{__DEFAULT_CONTEXT} ) {
 
         #create default context
-        my $context =
-          new Perl6::Pod::Parser::Context:: vars => { root => $self };
+        my $context = new Perl6::Pod::Parser::Context:: vars => { root=>$self };
 
         #setup defaults
         $self->{__DEFAULT_CONTEXT} = $context;
@@ -71,15 +69,12 @@ sub mk_block {
       || 'Perl6::Pod::Block';
 
     #      or die "Unknown block_type $name. Try =use ...";
-    #create class_options
-    my $class_options = $self->current_context->class_opts->{$name};
 
     #get prop
     my $block = $mod_name->new(
-        name          => $name,
-        context       => $self->current_context,
-        options       => $pod_opt,
-        class_options => $class_options
+        name    => $name,
+        context => $self->current_context,
+        options => $pod_opt
     );
 
 }
@@ -94,16 +89,16 @@ sub mk_fcode {
 
     #make first element
     my ( $name, $pod_opt ) = @_;
-    my $mod_name = $self->current_context->use->{ $name . "<>" }
+    my $mod_name = $self->current_context->use->{$name."<>"}
       || 'Perl6::Pod::FormattingCode';
 
     #      or die "Unknown block_type $name. Try =use ...";
+
     #get prop
     my $block = $mod_name->new(
-        name          => $name,
-        context       => $self->current_context,
-        options       => $pod_opt,
-        class_options => $self->current_context->class_opts->{ $name . "<>" }
+        name    => $name,
+        context => $self->current_context,
+        options => $pod_opt
     );
 
 }
@@ -156,12 +151,10 @@ sub on_start_element {
 sub on_start_block {
     my $self = shift;
     my $blk  = shift;
-
-    #    warn "start element ". $blk->local_name;
+#    warn "start element ". $blk->local_name;
     # call on_child for curretn element
     if ( my $elem = $self->current_element ) {
-
-#    warn "on child!" .$elem->local_name ." -> on_child( ". $blk->local_name.")";;
+    #    warn "on child!" .$elem->local_name ." -> on_child( ". $blk->local_name.")";;
 #        $elem->on_child( $blk)
     }
     $blk->start( $self, $blk->get_attr() );
@@ -176,7 +169,6 @@ sub on_end_element {
 sub on_end_block {
     my $self = shift;
     my $blk  = shift;
-
     $blk->end( $self, $blk->get_attr() );
     return $blk;
 
@@ -193,7 +185,7 @@ sub on_characters {
     return $self->on_para(@_);
 }
 
-############### 5 basic events
+############### 5 basic events 
 
 sub begin_input {
     my $self = shift;
@@ -202,162 +194,75 @@ sub begin_input {
 
 sub end_input {
     my $self = shift;
-    #begin flush for footers
-    if ( my $f = $self->{CODE_N_HASH} ) {
-        my $pod = "=begin _NOTES_\n";
-        foreach my $num ( sort keys %$f ) {
-            my $note = $f->{$num};
-            $pod .= "$num\t$note->{text}\n";
-        }
-        $pod .= "=end _NOTES_\n";
-        $self->_parse_chunk( \$pod );
-    }
     $self->end_document;
 }
 
+
 sub start_block {
     my $self = shift;
-    my ( $name, $opt, $str_num, $pelem, $first_line ) = @_;
-
-    #use item1 as item with attibute level
-    my $list_level;
-    if ( $name =~ /^item(\d+)/ ) {
-
-        #save level
-        $list_level = $1;
-
-        #rename block item123 to item
-        $name = 'item';
-    }
-    my $elem = ref($name) ? $name : $self->mk_block( $name, $opt );
-
-    #set lists level in attributes
-    if ( defined $list_level ) {
-        $elem->attrs_by_name->{level} = $list_level;
-    }
-
-    #save line num
-    $elem->context->custom->{_line_num_} = $str_num;
-
-    #save RAW header
-    if ($pelem) {
-        $elem->context->custom->{_RAW_} = $pelem->{RAW};
-    }
-    #save first_line of para ( if exists)
-    if ($first_line) {
-        $elem->context->custom->{_FIRST_PARA_LINE_} = $first_line;
-
-    }
+    my ( $name, $opt ,$str_num ) = @_;
+    my $elem = $self->mk_block( $name, $opt );
     $self->start_element($elem);
 }
 
+
 sub __expand_array_ref {
     my $self = shift;
-    my @res  = ();
-    for (@_) {
-        push @res, ref($_) eq 'ARRAY' ? $self->__expand_array_ref(@$_) : $_;
+    my @res = ();
+    for ( @_ ) {
+        push @res, ref($_) eq 'ARRAY' ? $self->__expand_array_ref(@$_) : $_
     }
-    @res;
+    @res
 }
-
 sub para {
     my $self = shift;
     my $txt  = shift;
-
     #hadnle block on_para
     if ( my $elem = $self->current_element ) {
-        $txt = $elem->on_para( $self, $txt );
-        return unless defined $txt;
-        if ( ref($txt) ) {
-            $self->run_para($txt);
-        }
-        else {
-            $self->_process_comm( $self->mk_characters($txt) );
-        }
+#        warn "process $txt" .$elem->local_name;
+        $txt = $elem->on_para($self, $txt);
+    }
+    my @content = $self->__expand_array_ref( $txt );
+    for ( @content) {
+        my $elements = ref($_) ? [$_] : [$self->mk_characters($_)];#$self->get_elements_from_ref( $self->parse_str($_) );
+        $self->_process_comm($_) for @$elements;
 
     }
+#    my $elems = $self->get_elements_from_ref( $self->parse_str($txt) );
+#    $self->_process_comm($_) for @$elems;
 }
 
 sub end_block {
     my $self = shift;
     my ( $name, $opt, $str_num ) = @_;
-    my $elem       = $self->current_element;    #mk_block($name, $opt);
-    my $last_block = $elem->local_name;
+    my $elem = $self->current_element;    #mk_block($name, $opt);
     $self->end_element($elem);
-
-    #save last processed block name
-    $self->current_context->custom->{_last_block_} = $last_block;
 }
 
-sub run_para {
+sub _parse_tree_ {
     my $self = shift;
-    my @in   = $self->__expand_array_ref(@_);
-    foreach my $el (@in) {
-        if ( UNIVERSAL::isa( $el, 'XML::ExtOn::Element' ) ) {
-            $self->_process_comm($el);
-            next;
+    my $elem = shift;
+    if ( ref($elem) ) {
+        if ( UNIVERSAL::isa( $elem, 'Pod::ParseTree' ) ) {
+            return [ map { ref($_) ? $self->_parse_tree_($_) : $_ }
+                  $elem->children ];
         }
-        unless ( exists $el->{type} ) {
-            $self->__process_events( $self->__make_events($el) );
-        }
-        else {
-            if ( $el->{type} eq 'para' ) {
-                $self->_process_comm( $self->mk_characters( $el->{data} ) );
+        elsif ( UNIVERSAL::isa( $elem, 'Pod::InteriorSequence' ) ) {
+            my %attr = ( name => $elem->cmd_name );
+            if ( my $ptree = $elem->parse_tree ) {
+                $attr{childs} = $self->_parse_tree_($ptree);
             }
+            return \%attr;
         }
     }
 }
 
-#make events for root parser
-sub __make_events {
+sub parse_str {
     my $self = shift;
-    my @res  = ();
-    foreach my $el (@_) {
-        unless ( ref($el) ) {
-            $el = { type => 'para', data => $el };
-        }
-
-        #process refs
-        if ( exists $el->{type} ) {
-            push @res, $el;
-        }
-        else {
-            my $name = $el->{name};
-
-            #make start stop
-            push @res,
-              {
-                type => 'start_fcode',
-                data => $name
-              },
-              $self->__make_events(
-                ref( $el->{childs} ) ? @{ $el->{childs} } : $el->{childs} ),
-              {
-                type => 'end_fcode',
-                data => $name
-              };
-        }
-    }
-    return @res;
-}
-
-sub __process_events {
-    my $self  = shift;
-    my $rootp = $self;    #->context->{vars}->{root};
-    foreach my $ev (@_) {
-        my $type = $ev->{type};
-        if ( $type eq 'para' ) {
-            $rootp->para( $ev->{data} );
-        }
-        else {
-
-            #process format code
-            my $fc = $self->mk_fcode( $ev->{data} );
-            ( $ev->{type} eq 'start_fcode' )
-              ? $rootp->start_block( $fc, '', 0 )
-              : $rootp->end_block( $fc, '', 0 );
-        }
-    }
+    my $str  = shift;
+    my $p    = new Pod::Parser::;
+    my $res  = $self->_parse_tree_( Pod::Parser->new->parse_text( $str, 123 ) );
+    return $res;
 }
 
 sub get_elements_from_ref {
@@ -384,28 +289,14 @@ sub get_elements_from_ref {
     return \@elems;
 }
 
-#make XML::ExtOn objects from array
-sub _make_elements {
-    my $self = shift;
-    my @res  = ();
-    for (@_) {
-        push @res, ref($_)
-          ? ref($_) eq 'ARRAY'
-              ? $self->_make_elements(@$_)
-              : $_
-          : $self->mk_characters($_);
-    }
-    return @res;
-}
+
 1;
 __END__
 
 
 =head1 SEE ALSO
 
-L<http://zag.ru/perl6-pod/S26.html>,
-Perldoc Pod to HTML converter: L<http://zag.ru/perl6-pod/>,
-Perl6::Pod::Lib
+L<http://perlcabal.org/syn/S26.html>
 
 =head1 AUTHOR
 
@@ -413,7 +304,7 @@ Zahatski Aliaksandr, <zag@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2010 by Zahatski Aliaksandr
+Copyright (C) 2009 by Zahatski Aliaksandr
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
